      SUBROUTINE CHEB(DEG,DEGMAX,PT1,PT2,NPT,T1,S1,S2,T2)
C     ****************************
C     * Compute T1 and T2 matrices
C     ****************************
      INTEGER DEG,DEGMAX,NPT
      DOUBLE PRECISION PT1(NPT),PT2(NPT),S1(NPT),S2(NPT),
     1     T1(0:DEGMAX,NPT),T2(0:DEGMAX,NPT)
C     **********************************************************************
C     * PARAMS type                i=input, o=output, a=auxiliary           
C     *
C     * DEG    integer             i degree of approximation
C     * DEGMAX integer             i maximum degree allowed
C     * PT1    double(NPT)         i array of the first coordinates of 
C     *                              the points
C     * PT2    double(NPT)         i array of the second coordinates of 
C     *                              the points
C     * NPT    integer             i number of points
C     * T1     double(0:DEG,NPT)   o Normalized Chebyshev polynomials at the
C     *                              first coordinate of the points
C     * S1     double(NPT)         i scale factors for the columns of T1
C     * S2     double(NPT)         i scale factors for the columns of T1
C     * T2     double(0:DEG,NPT)   o Normalized Chebyshev polynomials at the
C     *                              second coordinate of the points
C     **********************************************************************
      DOUBLE PRECISION SQRT2
      PARAMETER (SQRT2 = 1.4142135623730951D0)
      INTEGER I,J
C     ***************************
C     * LOCALS type
C     *
C     * SQRT2  double  sqrt(2.d0)
C     ***************************
C     ***********************
C     * Executable statements
C     ***********************
      IF (DEG .GE. 0) THEN
         DO 5 I = 1,NPT
            T1(0,I) = S1(I) * S2(I)
            T2(0,I) = 1.0D0
 5       CONTINUE
      END IF      
      IF (DEG .GE. 1) THEN
         DO 10 I = 1,NPT
            T1(1,I) = SQRT2 * PT1(I) * S1(I) * S2(I)
            T2(1,I) = SQRT2 * PT2(I) 
 10      CONTINUE
      END IF
      IF (DEG .GE. 2) THEN
         DO 15 I = 1,NPT
            T1(2,I) = 2 * PT1(I) * T1(1,I) - SQRT2 * T1(0,I)
            T2(2,I) = 2 * PT2(I) * T2(1,I) - SQRT2 * T2(0,I)
 15      continue
      end if
      if (deg .ge. 3) then
         DO 20 I = 1,NPT
            DO 25 J = 3,DEG
               T1(J,I) = 2 * PT1(I) * T1(J - 1,I) - T1(J - 2,I)
               T2(J,I) = 2 * PT2(I) * T2(J - 1,I) - T2(J - 2,I)
 25         CONTINUE
 20      CONTINUE
      END IF
      RETURN
      END

